@@ -27,7 +27,6 @@
 #ifndef __G_CONVERT_H__
 #define __G_CONVERT_H__
 
-#include <stddef.h>      /* For size_t */
 #include <glib/gerror.h>
 
 G_BEGIN_DECLS
@@ -51,7 +50,7 @@ typedef struct _GIConv *GIConv;
 
 GIConv g_iconv_open   (const gchar  *to_codeset,
 		       const gchar  *from_codeset);
-size_t g_iconv        (GIConv        converter,
+gsize  g_iconv        (GIConv        converter,
 		       gchar       **inbuf,
 		       gsize        *inbytes_left,
 		       gchar       **outbuf,
@@ -101,6 +100,8 @@ gchar* g_locale_from_utf8 (const gchar  *utf8string,
 #ifdef G_OS_WIN32
 #define g_filename_to_utf8 g_filename_to_utf8_utf8
 #define g_filename_from_utf8 g_filename_from_utf8_utf8
+#define g_filename_from_uri g_filename_from_uri_utf8
+#define g_filename_to_uri g_filename_to_uri_utf8 
 #endif
 
 gchar* g_filename_to_utf8   (const gchar  *opsysstring,
@@ -124,6 +125,8 @@ gchar *g_filename_to_uri   (const gchar *filename,
 gchar *g_filename_display_name (const gchar *filename) G_GNUC_MALLOC;
 gboolean g_get_filename_charsets (G_CONST_RETURN gchar ***charsets);
 
+gchar *g_filename_display_basename (const gchar *filename) G_GNUC_MALLOC;
+
 gchar **g_uri_list_extract_uris (const gchar *uri_list) G_GNUC_MALLOC;
 
 G_END_DECLS
